pub enum CommandError {
InvalidParameter(String),
InvalidParameterCount {
actual: u32,
compare_op: ParamCountCheck,
},
CommandFailure(Box<dyn Error + Send>),
}Expand description
Errors that can be encountered during command execution.
Variants
InvalidParameter(String)
The given parameter is invalid for this command, or there is no command that matches said parameter.
InvalidParameterCount
The count of parameters is invalid for this command.
CommandFailure(Box<dyn Error + Send>)
Generalized catch-all for all other failure types.