pub struct Connection(/* private fields */);Expand description
An opaque ID type representing a single endpoint-to-endpoint connection.
Connections are created and managed by the Networking stack. This ID type can only be used to
identify, and does not contain detailed information about the connection. Instead, detailed
information can be found by querying the Networking stack via Networking::connection_info().
Implementations
Sourceimpl Connection
impl Connection