pub struct TickLoopHandle { /* private fields */ }Expand description
Handle for a threaded tick loop.
This handle doesn’t really do anything by itself, but represents a tick loop running in a separate thread. This handle is not cloneable, and will stop and join the tick loop thread when it is dropped.
use gtether::util::tick_loop::TickLoopBuilder;
let join_handle = TickLoopBuilder::new()
// These init()/tick() closures are noops
.init(|| Ok::<(), ()>(()))
.tick(|_, _| true)
// Spawn a threaded tick loop
.spawn()?;
// Drop the join_handle to stop and join the threaded tick loop
drop(join_handle);Trait Implementations
Sourceimpl Debug for TickLoopHandle
impl Debug for TickLoopHandle
Sourceimpl Drop for TickLoopHandle
impl Drop for TickLoopHandle