pub struct Networking<D: NetDriver> { /* private fields */ }Expand description
Networking stack for managing OSI host layers 5 (session) and 6 (presentation).
This structure maintains user-side networking sessions and connections. It also manages the presentation layer, by accepting layer 7 (application) Messages to present downwards to layer 4 (transport) and below.
See module-level documentation for more details.
Implementations
Sourceimpl<D: NetDriver> Networking<D>
impl<D: NetDriver> Networking<D>
Sourcepub fn new(driver_factory: impl NetDriverFactory<D>) -> Self
pub fn new(driver_factory: impl NetDriverFactory<D>) -> Self
Create a new Networking stack using a particular NetDriver implementation.
Sourcepub fn event_bus(&self) -> &EventBusRegistry
pub fn event_bus(&self) -> &EventBusRegistry
Get the EventBusRegistry to register event handlers.
Available events:
Sourcepub fn insert_msg_handler<M, E>(&self, handler: impl MessageHandler<M, E>)
pub fn insert_msg_handler<M, E>(&self, handler: impl MessageHandler<M, E>)
Insert a message handler into this Networking stack.
The handler is associated with the message type’s key, and inserting multiple handlers with the same key will override the old one.
Sourcepub fn connection_info(&self, connection: &Connection) -> Option<ConnectionInfo>
pub fn connection_info(&self, connection: &Connection) -> Option<ConnectionInfo>
Retrieve detailed ConnectionInfo for a particular Connection.
If there is no Connection or it has been closed, yields None.
Sourcepub async fn close(&self)
pub async fn close(&self)
Close the Networking stack.
Closes the stack if it is open (e.g. has been connected or listened). It is likely that any future operations will yield NetworkingError::Closed until the stack is reset.
Note that the Networking stack will automatically close itself when dropped, so it is not necessary to explicitly call this before dropping the stack.
Sourcepub fn close_blocking(&self)
pub fn close_blocking(&self)
Convenience wrapper for a sync version of Self::close().
Sourceimpl<D: NetDriverConnect> Networking<D>
impl<D: NetDriverConnect> Networking<D>
Sourcepub async fn connect(
&self,
socket_addr: SocketAddr,
) -> Result<ClientConnectContext, NetworkingError>
pub async fn connect( &self, socket_addr: SocketAddr, ) -> Result<ClientConnectContext, NetworkingError>
Attempt to connect to the remote socket_addr.
How many endpoints can be connected to is up to the particular driver. For example, a client/server architecture may only allow a client to connect to one server at a time, whereas a peer-to-peer architecture may allow clients to connect to many other clients at once. See the driver’s documentation for more details.
Errors
NetworkingError::InvalidAddress if the socket_addr could not be
connected to.
NetworkingError::Cancelled if the connection was cancelled by event handling.
Sourcepub fn connect_sync(
&self,
socket_addr: SocketAddr,
) -> Result<ClientConnectContext, NetworkingError>
pub fn connect_sync( &self, socket_addr: SocketAddr, ) -> Result<ClientConnectContext, NetworkingError>
Convenience wrapper for a sync version of Self::connect().
Sourceimpl<D: NetDriverCloseConnection> Networking<D>
impl<D: NetDriverCloseConnection> Networking<D>
Sourcepub async fn close_connection(&self, connection: Connection)
pub async fn close_connection(&self, connection: Connection)
Close the specified Connection.
This method is idempotent, and specifying a non-existing Connection ID will do nothing.
Sourceimpl<D: NetDriverListen> Networking<D>
impl<D: NetDriverListen> Networking<D>
Sourcepub async fn listen(
&self,
socket_addr: SocketAddr,
) -> Result<(), NetworkingError>
pub async fn listen( &self, socket_addr: SocketAddr, ) -> Result<(), NetworkingError>
Bind to and listen on a socket.
Errors
NetworkingError::InvalidAddress if the socket_addr could not be bound.
Sourceimpl<D: NetDriverSend> Networking<D>
impl<D: NetDriverSend> Networking<D>
Sourcepub fn send<M>(&self, msg: impl Into<Message<M>>) -> Result<(), NetworkingError>where
M: MessageSend,
pub fn send<M>(&self, msg: impl Into<Message<M>>) -> Result<(), NetworkingError>where
M: MessageSend,
Send a Message.
Messages are dispatched immediately. This method does not block or otherwise wait.
Errors
NetworkingError::MalformedMessage if the Message couldn’t be encoded into bytes.
NetworkingError::Closed if the connection is closed.
Sourcepub fn send_recv<M>(
&self,
msg: impl Into<Message<M>>,
) -> Result<MessageReplyFuture<M::Reply>, NetworkingError>
pub fn send_recv<M>( &self, msg: impl Into<Message<M>>, ) -> Result<MessageReplyFuture<M::Reply>, NetworkingError>
Send a repliable Message and get a reply future.
Messages are dispatched immediately. This method does not block or otherwise wait, however the returned reply future can be waited on.
Errors
NetworkingError::MalformedMessage if the Message couldn’t be encoded into bytes.
NetworkingError::Closed if the connection is closed.
Sourceimpl<D: NetDriverSendTo> Networking<D>
impl<D: NetDriverSendTo> Networking<D>
Sourcepub fn send_to<M>(
&self,
connection: Connection,
msg: impl Into<Message<M>>,
) -> Result<(), NetworkingError>where
M: MessageSend,
pub fn send_to<M>(
&self,
connection: Connection,
msg: impl Into<Message<M>>,
) -> Result<(), NetworkingError>where
M: MessageSend,
Send a Message to a specific Connection.
Messages are dispatched immediately. This method does not block or otherwise wait.
Errors
NetworkingError::InvalidConnection if the Connection does not exist.
NetworkingError::MalformedMessage if the Message couldn’t be encoded into bytes.
NetworkingError::Closed if the driver is closed (e.g. no longer listening on a socket in the case of a server).
Sourcepub fn send_recv_to<M>(
&self,
connection: Connection,
msg: impl Into<Message<M>>,
) -> Result<MessageReplyFuture<M::Reply>, NetworkingError>
pub fn send_recv_to<M>( &self, connection: Connection, msg: impl Into<Message<M>>, ) -> Result<MessageReplyFuture<M::Reply>, NetworkingError>
Send a repliable Message to a specific Connection and get a reply future.
Messages are dispatched immediately. This method does not block or otherwise wait, however the returned reply future can be waited on.
Errors
NetworkingError::InvalidConnection if the Connection does not exist.
NetworkingError::MalformedMessage if the Message couldn’t be encoded into bytes.
NetworkingError::Closed if the driver is closed (e.g. no longer listening on a socket in the case of a server).
Sourceimpl<D: NetDriverBroadcast> Networking<D>
impl<D: NetDriverBroadcast> Networking<D>
Sourcepub fn broadcast<M>(
&self,
msg: impl Into<Message<M>>,
) -> Result<(), NetworkingError>where
M: MessageSend,
pub fn broadcast<M>(
&self,
msg: impl Into<Message<M>>,
) -> Result<(), NetworkingError>where
M: MessageSend,
Broadcast a Message to all Connections.
Messages are dispatched immediately. This method does not block or otherwise wait.
Errors
NetworkingError::MalformedMessage if the Message couldn’t be encoded into bytes.
NetworkingError::Closed if the driver is closed (e.g. no longer listening on a socket in the case of a server).