pub struct DependencyGraph { /* private fields */ }Expand description
A graph of dependency relations between resources.
Dependency relations can be traversed via DependencyNodes. Any resource that
has dependencies or dependents can be accessed via DependencyGraph::get().
DependencyGraphs are comparable via equivalence relations.
Implementations
Sourceimpl DependencyGraph
impl DependencyGraph
Sourcepub fn builder() -> DependencyGraphBuilder
pub fn builder() -> DependencyGraphBuilder
Create a DependencyGraphBuilder.
This can be useful to construct a populated DependencyGraph in e.g. unit tests.
Sourcepub fn clear_dependencies(&mut self, id: &ResourceId)
pub fn clear_dependencies(&mut self, id: &ResourceId)
Clear all dependency relations for a particular resource in this graph.
use gtether::resource::id::ResourceId;
use gtether::resource::manager::dependency::DependencyGraph;
let mut graph = DependencyGraph::builder().add("a", ["b", "c"]).add("b", ["c"]).build();
let expected_graph = DependencyGraph::builder().add("b", ["c"]).build();
let id = ResourceId::from("a");
graph.clear_dependencies(&id);
assert_eq!(graph, expected_graph);
assert_eq!(graph.get(&id), None);Sourcepub fn add_dependency(&mut self, id: ResourceId, dependency: ResourceId)
pub fn add_dependency(&mut self, id: ResourceId, dependency: ResourceId)
Add a dependency relation for a particular resource in this graph.
use gtether::resource::id::ResourceId;
use gtether::resource::manager::dependency::DependencyGraph;
let mut graph = DependencyGraph::builder().add("a", ["b"]).build();
let expected_graph = DependencyGraph::builder().add("a", ["b", "c"]).build();
graph.add_dependency(ResourceId::from("a"), ResourceId::from("c"));
assert_eq!(graph, expected_graph);Sourcepub fn set_dependencies(
&mut self,
id: ResourceId,
dependencies: impl IntoIterator<Item = ResourceId>,
)
pub fn set_dependencies( &mut self, id: ResourceId, dependencies: impl IntoIterator<Item = ResourceId>, )
Set the dependency relations for a particular resource in this graph.
use gtether::resource::id::ResourceId;
use gtether::resource::manager::dependency::DependencyGraph;
let mut graph = DependencyGraph::builder().add("a", ["b", "c"]).build();
let expected_graph = DependencyGraph::builder().add("a", ["d", "e"]).build();
graph.set_dependencies(ResourceId::from("a"), [ResourceId::from("d"), ResourceId::from("e")]);
assert_eq!(graph, expected_graph);Sourcepub fn get(&self, id: &ResourceId) -> Option<DependencyNode<'_>>
pub fn get(&self, id: &ResourceId) -> Option<DependencyNode<'_>>
Get a DependencyNode for a particular resource in this graph.
If the given resource does not have any dependencies or dependents, it will not be in the
graph, and so this method will return None.
use gtether::resource::id::ResourceId;
use gtether::resource::manager::dependency::DependencyGraph;
let graph = DependencyGraph::builder().add("a", ["b"]).build();
let id_a = ResourceId::from("a");
let id_b = ResourceId::from("b");
let id_c = ResourceId::from("c");
assert_eq!(graph.get(&id_a).unwrap().id(), &id_a);
assert_eq!(graph.get(&id_b).unwrap().id(), &id_b);
assert_eq!(graph.get(&id_c), None);Sourcepub fn iter(&self) -> Iter<'_> ⓘ
pub fn iter(&self) -> Iter<'_> ⓘ
Iterate over all dependencies in this graph, in no particular order.
This will only iterate over nodes that have dependencies, and will not iterate over leaf nodes.
use std::collections::HashSet;
use gtether::resource::id::ResourceId;
use gtether::resource::manager::dependency::DependencyGraph;
let graph = DependencyGraph::builder().add("a", ["b", "c"]).add("b", ["c"]).build();
let expected_ids = ["a", "b"].into_iter()
.map(ResourceId::from)
.collect::<HashSet<_>>();
let ids = graph.iter()
.map(|node| node.id().clone())
.collect::<HashSet<_>>();
assert_eq!(ids, expected_ids);Trait Implementations
Sourceimpl Clone for DependencyGraph
impl Clone for DependencyGraph
Sourcefn clone(&self) -> DependencyGraph
fn clone(&self) -> DependencyGraph
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for DependencyGraph
impl Debug for DependencyGraph
Sourceimpl Default for DependencyGraph
impl Default for DependencyGraph
Sourcefn default() -> DependencyGraph
fn default() -> DependencyGraph
impl Eq for DependencyGraph
Sourceimpl PartialEq for DependencyGraph
impl PartialEq for DependencyGraph
Sourcefn eq(&self, other: &DependencyGraph) -> bool
fn eq(&self, other: &DependencyGraph) -> bool
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DependencyGraph