pub struct WorkTask<T: 'static> { /* private fields */ }Expand description
The self-referencing struct.
Implementations
Sourceimpl<T: 'static> WorkTask<T>
impl<T: 'static> WorkTask<T>
Sourcepub fn spawn<W>(work: Box<W>) -> (Box<dyn Work<Output = ()>>, Self)
pub fn spawn<W>(work: Box<W>) -> (Box<dyn Work<Output = ()>>, Self)
Create a new WorkTask from an existing Work item.
This does not queue or otherwise execute the Work item, but only creates the task handle. This API is usually used inside WorkSources, and should not be needed by an end user to execute a Work item.
Sourcepub fn try_poll(self) -> Result<WorkTaskResult<T>, Self>
pub fn try_poll(self) -> Result<WorkTaskResult<T>, Self>
Attempt to synchronously poll the task for completion.
If the task has completed, this will yield the task’s output. If the task has not yet completed, the task will be returned for later re-polling.
This is a synchronous alternative to awaiting the task.
use gtether::worker::WorkTask;
let (work, task) = WorkTask::spawn(Box::new(|| true));
let task = task.try_poll()
.expect_err("task should not be completed");
work.execute();
let output = task.try_poll()
.expect("task should be completed")
.expect("task should not be cancelled");
assert_eq!(output, true);Trait Implementations